Welcome to pictool's documentation!
===================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:


Installation
------------
For running :program:`pictool`, OpenCV_ and gexiv2_ need to be installed. Usually, both
are included in different distributions (like openSUSE_ or Debian_) and can
be installed via the available package manager (like :program:`zypper` or :program:`apt`).

When the requirements are installed, you can install :program:`pictool` via :program:`pip`::

  pip install pictool


.. _OpenCV: https://opencv.org/
.. _gexiv2: https://wiki.gnome.org/Projects/gexiv2
.. _openSUSE: https://opensuse.org/
.. _Debian: https://www.debian.org/
